//
//  WorldScoreboardController.swift
//  Pendu
//
//  Created by Sofiane Lasri-Trienpont on 13/06/2023.
//

import UIKit

class WorldScoreboardController: UIViewController, UITableViewDataSource {

    @IBOutlet weak var scoreTable: UITableView!
    // Structure pour représenter les données JSON
    struct ScoreData: Codable {
        let categoryName: String
        let difficulty: String
        let playerName: String
        let score: Int
    }
    
    // Tableau pour stocker les données JSON
    var scores: [ScoreData] = []
    
    override func viewDidLoad() {
        super.viewDidLoad()
        scoreTable.register(UITableViewCell.self, forCellReuseIdentifier: "ScoreCell")
        // Appeler la fonction pour récupérer les données JSON
        fetchJSONData()
        
        // Définir le contrôleur en tant que dataSource du TableView
        scoreTable.dataSource = self
    }
    
    func fetchJSONData() {
        // URL de la liste JSON
        guard let url = URL(string: "https://miscs.sl-projects.com/IUT-ORSAY/LP-PRISM/TP-iOS/") else {
            print("URL invalide")
            return
        }
        
        URLSession.shared.dataTask(with: url) { [weak self] (data, _, error) in
            guard let data = data else {
                if let error = error {
                    print("Erreur lors de la récupération des données : \(error.localizedDescription)")
                }
                return
            }
            
            do {
                // Décoder les données JSON
                let decoder = JSONDecoder()
                self?.scores = try decoder.decode([ScoreData].self, from: data)
                
                // Mettre à jour le TableView sur le thread principal
                DispatchQueue.main.async {
                    self?.scoreTable.reloadData()
                }
            } catch {
                print("Erreur lors du décodage des données JSON : \(error.localizedDescription)")
            }
        }.resume()
    }
    
    // Méthodes requises pour le UITableViewDataSource
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return scores.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "ScoreCell", for: indexPath)
        
        let score = scores[indexPath.row]
        
        // Afficher les données dans les cellules du TableView
        cell.textLabel?.text = "\(score.playerName) | \(score.categoryName) - \(score.difficulty) - \(score.score) pts"
        
        return cell
    }

}
